use crate::handles::online_users_update::send_online_users_resp;
use tokio::sync::mpsc;

// 假设的用户详细信息结构体
#[derive(Debug)]
pub struct UserDetails {
    pub username: String,
}

// 定义事件类型
#[derive(Debug)]
pub enum Event {
    NewConnection(String),
    CloseConnection(String),
    UpdateOnlineUsers,
}

// 处理事件的任务
pub async fn handle_events(mut receiver: mpsc::UnboundedReceiver<Event>) {
    while let Some(event) = receiver.recv().await {
        match event {
            Event::NewConnection(from_id) => {
                println!("新连接: {}", from_id);
                // 这里假设在其他地方有获取所有连接发送器的逻辑，暂时省略
                // 实际应用中，需要实现向所有连接发送消息的功能
                if let Err(e) = send_online_users_resp().await {
                    println!(
                        "在处理新用户id {} 之时广播，处理在线用户列表出错了：{:?}",
                        &from_id, e
                    );
                }
            }
            Event::CloseConnection(from_id) => {
                println!("关闭连接: {}", from_id);
                if let Err(e) = send_online_users_resp().await {
                    println!(
                        "在处理新用户id {} 之时广播，处理在线用户列表出错了：{:?}",
                        &from_id, e
                    );
                }
            }
            Event::UpdateOnlineUsers => {
                // 这里可以实现其他触发更新在线用户列表的逻辑
                // 为简单起见，暂未详细实现
                println!("更新在线用户列表事件触发");
            }
        }
    }
}
