use crate::handles::online_users_update::send_online_users_resp;
use crate::handles::redis::remove_this_connection;
use crate::typing::used_typed::{ConnectionMap};
use tokio::sync::RwLockWriteGuard;

pub async fn handle_connection_error(
    from_id: &str,
    connections: &ConnectionMap,
) {
    println!("开始处理用户id: {} 的连接错误", from_id);
    // 从全局连接映射中移除该连接
    let removed = {
        let mut connections: RwLockWriteGuard<'_, _> = connections.write().await;
        println!("清除之前的keys {:?}", connections.keys());
        let result = connections.remove(from_id).is_some();
        println!("清除之后的keys {:?}", connections.keys());
        result
    };

    println!(
        "是否成功从全局连接映射中移除用户id: {}，结果: {}",
        from_id, removed
    );

    // 从 Redis 中移除该用户的信息
    if removed {
        if let Err(e) = remove_this_connection(from_id).await {
            println!("从 Redis 中移除用户信息时出错: {}", e);
        }
    }

    // 准备更新用户链接
    if let Err(e) = send_online_users_resp().await {
        println!("在处理新用户id {} 之时广播，处理在线用户列表出错了：{:?}", &from_id,e);
    } else {
        println!("成功将用户id {} 退出广播至其余用户", &from_id);
    }
}