use std::collections::HashMap;

// 提取出来的处理握手的函数
pub(crate) fn handle_handshake(
    req: &tungstenite::handshake::server::Request,
    must_existed_params: &[&str],
    static_ws_pwd: &str,
) -> Result<HashMap<String, String>, String> {
    println!("新客户端连接: {}", req.uri());
    let connection_params = match crate::utils::utils::get_connection_params(req.uri().to_string()) {
        Ok(p) => p,
        Err(e) => {
            let error_msg = format!("缺少重要连接数据段: {}", e);
            println!("{}", error_msg);
            return Err(error_msg);
        }
    };

    let not_existed = must_existed_params
        .iter()
        .find(|param| !connection_params.contains_key(&param.to_string()));

    if let Some(param) = not_existed {
        let error_msg = format!("缺少重要连接数据段: {}", param);
        println!("{}", error_msg);
        return Err(error_msg);
    }

    if connection_params.get("wsPwd").unwrap() != static_ws_pwd {
        println!("wsPwd不正确！");
        return Err("wsPwd不正确！".to_string());
    }

    Ok(connection_params)
}