use crate::client::{CONNECTIONS, ONLINE_USERS};
use crate::utils::json_utils::get_current_timestamp;
use futures::SinkExt;
use serde::{Deserialize, Serialize};
use tungstenite::{Error, Message};

#[derive(Serialize, Deserialize, Debug, Clone)]
pub struct OnlineUserMessage {
    #[serde(rename = "callState")]
    pub call_state: String,
    #[serde(rename = "channelID")]
    pub channel_id: String,
    #[serde(rename = "deviceID")]
    pub device_id: String,
    #[serde(rename = "fromID")]
    pub from_id: String,
    #[serde(rename = "hasCamera")]
    pub has_camera: String,
    #[serde(rename = "hasMike")]
    pub has_mike: String,
    #[serde(rename = "isHost")]
    pub is_host: String,
    #[serde(rename = "userCallGroup")]
    pub user_call_group: String,
    #[serde(rename = "fromName")]
    pub from_name: String,
}

#[derive(Serialize, Deserialize, Debug)]
pub struct OnlineUsersMessage {
    #[serde(rename = "msgType")]
    pub msg_type: String,
    #[serde(rename = "fromId")]
    pub from_id: String,
    #[serde(rename = "fromName")]
    pub from_name: String,
    #[serde(rename = "toId")]
    pub to_id: String,
    #[serde(rename = "msgData")]
    pub msg_data: Vec<OnlineUserMessage>,
    #[serde(rename = "time")]
    pub time: u128,
}


pub async fn send_online_users_resp() -> Result<(), Error> {
    let mut msg_data = Vec::new();
    {
        let online_users = ONLINE_USERS.read().await;
        println!("当前所有用户数据信息 ONLINE_USERS: {:?}", online_users);
        for (_, user_info_str) in online_users.iter() {
            let parts: Vec<&str> = user_info_str.split(',').collect();
            if parts.len() == 9 {
                let user_msg = OnlineUserMessage {
                    call_state: parts[0].to_string(),
                    channel_id: parts[1].to_string(),
                    device_id: parts[2].to_string(),
                    from_id: parts[3].to_string(),
                    has_camera: parts[4].to_string(),
                    has_mike: parts[5].to_string(),
                    is_host: parts[6].to_string(),
                    user_call_group: parts[7].to_string(),
                    from_name: parts[8].to_string(),
                };
                msg_data.push(user_msg);
            }
        }
    }

    let mut connections = CONNECTIONS.write().await;
    println!("当前的connections的keys是 {:?}", connections.keys());
    for (from_id, connection) in connections.iter_mut() {
        let to_id = from_id.to_string();
        let message = OnlineUsersMessage {
            msg_type: "CmdUpdateOnlineUsers".to_string(),
            from_id: "0".to_string(),
            from_name: "Server".to_string(),
            to_id,
            msg_data: msg_data.clone(),
            time: get_current_timestamp(),
        };

        let json_result = serde_json::to_string(&message);
        if let Err(e) = json_result {
            println!("序列化消息给用户 {} 失败: {}", from_id.to_string(), e);
            continue;
        }
        let json = json_result.unwrap();

        if let Err(e) = connection.sender.send(Message::text(json)).await {
            println!("发送消息给用户 {} 失败: {}", from_id.to_string(), e);
        }
    }
    Ok(())
}
